Agnostica is a platform-agnostic library to make the creation of chat bots that function on multiple platforms more simple and streamlined.

## Documentation

Documentation is currently a work in progress.

## Support

There is currently not yet a support server for the library.

<!-- [![shield](https://shields.yoki-labs.xyz/shields/vanity/agnostica)](https://guilded.gg/agnostica) -->